@@ -1,5 +1,4 @@
-use crate::*;
-
+use super::*;
 use bindings::Windows::Win32::System::Com::{CoTaskMemAlloc, CoTaskMemFree};
 
 /// A WinRT array stores elements contiguously in a heap-allocated buffer.
@@ -36,9 +35,7 @@ impl<T: RuntimeType> Array<T> {
         // We ensured we alloc enough space by multiplying len * size_of::<T>
         let data = unsafe { CoTaskMemAlloc(bytes_amount) as *mut T::DefaultType };
 
-        if data.is_null() {
-            panic!("Could not successfully allocate for Array");
-        }
+        assert!(!data.is_null(), "Could not successfully allocate for Array");
 
         // SAFETY: It is by definition safe to zero-initialize WinRT types.
         // `write_bytes` will write 0 to (len * size_of::<T>())
@@ -52,6 +49,13 @@ impl<T: RuntimeType> Array<T> {
         Self { data, len }
     }
 
+    /// Creates an array by copying the elements from the slice.
+    pub fn from_slice(values: &[T::DefaultType]) -> Self {
+        let mut array = Self::with_len(values.len());
+        array.clone_from_slice(values);
+        array
+    }
+
     /// Returns `true` if the array is empty.
     pub fn is_empty(&self) -> bool {
         self.len == 0
