@@ -1,5 +1,5 @@
-use crate::*;
-use bindings::Windows::Win32::Foundation::CO_E_NOTINITIALIZED;
+use super::*;
+use bindings::Windows::Win32::Graphics::DirectDraw::CO_E_NOTINITIALIZED;
 use std::marker::PhantomData;
 use std::sync::atomic::{AtomicPtr, Ordering};
 
@@ -79,7 +79,7 @@ pub fn factory<C: RuntimeName, I: Interface>() -> Result<I> {
 
         // If this fails because combase hasn't been loaded yet then load combase
         // automatically so that it "just works" for apartment-agnostic code.
-        if code == CO_E_NOTINITIALIZED {
+        if code == HRESULT(CO_E_NOTINITIALIZED as _) {
             let mut _cookie = std::ptr::null_mut();
 
             // Won't get any delay-load errors here if we got CO_E_NOTINITIALIZED, so quiet the
@@ -139,6 +139,6 @@ demand_load! {
         fn CoIncrementMTAUsage(cookie: *mut RawPtr) -> HRESULT;
     }
     "combase.dll" {
-        fn RoGetActivationFactory(hstring: std::mem::ManuallyDrop<HSTRING>, interface: &Guid, result: *mut RawPtr) -> HRESULT;
+        fn RoGetActivationFactory(hstring: std::mem::ManuallyDrop<HSTRING>, interface: &GUID, result: *mut RawPtr) -> HRESULT;
     }
 }
